==> trade-center-api-2.3.52-1-sources.jar: cn/com/duiba/order/center/api/paramquery/AabnormalOrderQueryParams.java <==
package cn.com.duiba.order.center.api.paramquery;

/**
 * @author heyichao
 * @date 2020/2/13
 */

import java.io.Serializable;
import java.util.Date;

/**
 * 异常订单查询类
 */
public class AabnormalOrderQueryParams implements Serializable{

    private static final long serialVersionUID = -7119065949124247935L;
    private String type;

    private Integer facePrice;

    private String orderNum;

    private String searchType;

    private Date startTime;

    private Date endTime;

    private Date objectEndTime;

    private Date timeoutTime;

    private Date createTime;

    private Integer offset; // 分页偏移量

    private Integer max; // 每页个数

    private Long maxId;

    private String lotteryType;//游戏类型

    private Long appId;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Date getObjectEndTime() {
        return objectEndTime;
    }

    public void setObjectEndTime(Date objectEndTime) {
        this.objectEndTime = objectEndTime;
    }

    public Date getTimeoutTime() {
        return timeoutTime;
    }

    public void setTimeoutTime(Date timeoutTime) {
        this.timeoutTime = timeoutTime;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getSearchType() {
        return searchType;
    }

    public void setSearchType(String searchType) {
        this.searchType = searchType;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public void setMax(Integer max) {
        this.max = max;
    }


    public AabnormalOrderQueryParams() {
    }

    public Integer getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Integer facePrice) {
        this.facePrice = facePrice;
    }

    public Long getMaxId() {
        return maxId;
    }

    public void setMaxId(Long maxId) {
        this.maxId = maxId;
    }

    public AabnormalOrderQueryParams(String type, Integer facePrice, String orderNum, String searchType) {
        this.type = type;
        this.facePrice = facePrice;
        this.orderNum = orderNum;
        this.searchType = searchType;
    }

    public String getLotteryType() {
        return lotteryType;
    }

    public void setLotteryType(String lotteryType) {
        this.lotteryType = lotteryType;
    }


}

==> trade-center-api-3.0.2-sources.jar: cn/com/duiba/order/center/api/paramquery/AabnormalOrderQueryParams.java <==
package cn.com.duiba.order.center.api.paramquery;

/**
 * @author heyichao
 * @date 2020/2/13
 */

import java.io.Serializable;
import java.util.Date;

/**
 * 异常订单查询类
 */
public class AabnormalOrderQueryParams implements Serializable{

    private static final long serialVersionUID = -7119065949124247935L;
    private String type;

    private Integer facePrice;

    private String orderNum;

    private String searchType;

    private Date startTime;

    private Date endTime;

    private Date objectEndTime;

    private Date timeoutTime;

    private Date createTime;

    private Integer offset; // 分页偏移量

    private Integer max; // 每页个数

    private Long maxId;

    private String lotteryType;//游戏类型

    private Long appId;

    private String account;

    private Long itemId;

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Date getObjectEndTime() {
        return objectEndTime;
    }

    public void setObjectEndTime(Date objectEndTime) {
        this.objectEndTime = objectEndTime;
    }

    public Date getTimeoutTime() {
        return timeoutTime;
    }

    public void setTimeoutTime(Date timeoutTime) {
        this.timeoutTime = timeoutTime;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getSearchType() {
        return searchType;
    }

    public void setSearchType(String searchType) {
        this.searchType = searchType;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public void setMax(Integer max) {
        this.max = max;
    }


    public AabnormalOrderQueryParams() {
    }

    public Integer getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Integer facePrice) {
        this.facePrice = facePrice;
    }

    public Long getMaxId() {
        return maxId;
    }

    public void setMaxId(Long maxId) {
        this.maxId = maxId;
    }

    public AabnormalOrderQueryParams(String type, Integer facePrice, String orderNum, String searchType) {
        this.type = type;
        this.facePrice = facePrice;
        this.orderNum = orderNum;
        this.searchType = searchType;
    }

    public String getLotteryType() {
        return lotteryType;
    }

    public void setLotteryType(String lotteryType) {
        this.lotteryType = lotteryType;
    }


}
